@@ -1,6 +1,6 @@
 /**
  * @file db.c sqlite backend
- * 
+ *
  * Copyright (C) 2007-2020  Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -40,9 +40,9 @@ static GHashTable *statements = NULL;
 static void db_view_remove (const gchar *id);
 
 static void
-db_prepare_stmt (sqlite3_stmt **stmt, const gchar *sql) 
+db_prepare_stmt (sqlite3_stmt **stmt, const gchar *sql)
 {
-	gint		res;	
+	gint		res;
 	const char	*left;
 
 	res = sqlite3_prepare_v2 (db, sql, -1, stmt, &left);
@@ -58,7 +58,7 @@ db_prepare_stmt (sqlite3_stmt **stmt, const gchar *sql)
 static void
 db_new_statement (const gchar *name, const gchar *sql)
 {
-	
+
 	if (!statements)
 		statements = g_hash_table_new (g_str_hash, g_str_equal);
 
@@ -76,7 +76,7 @@ db_get_statement (const gchar *name)
 	db_prepare_stmt (&statement, sql);
 
 	if (!statement)
-		g_error ("Fatal: unknown prepared statement \"%s\" requested!", name);	
+		g_error ("Fatal: unknown prepared statement \"%s\" requested!", name);
 
 	sqlite3_reset (statement);
 	return statement;
@@ -87,7 +87,7 @@ db_exec (const gchar *sql)
 {
 	gchar	*err;
 	gint	res;
-	
+
 	debug1 (DEBUG_DB, "executing SQL: %s", sql);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
 	if (1 >= res) {
@@ -110,7 +110,7 @@ db_table_exists (const gchar *name)
 	sqlite3_reset (stmt);
 	if (SQLITE_ROW == sqlite3_step (stmt))
 		res = sqlite3_column_int (stmt, 0);
-	
+
 	sqlite3_finalize (stmt);
 	sqlite3_free (sql);
 	return (1 == res);
@@ -133,7 +133,7 @@ db_get_schema_version (void)
 {
 	guint		schemaVersion = 0;
 	sqlite3_stmt	*stmt;
-	
+
 	if (!db_table_exists ("info")) {
 		db_exec ("CREATE TABLE info ( "
 		         "   name	TEXT, "
@@ -142,12 +142,12 @@ db_get_schema_version (void)
 		         ");");
 		db_set_schema_version (-1);
 	}
-	
+
 	db_prepare_stmt (&stmt, "SELECT value FROM info WHERE name = 'schemaVersion'");
 	if (SQLITE_ROW == sqlite3_step (stmt))
 		schemaVersion = sqlite3_column_int (stmt, 0);
 	sqlite3_finalize (stmt);
-	
+
 	return schemaVersion;
 }
 
@@ -156,24 +156,24 @@ db_begin_transaction (void)
 {
 	gchar	*sql, *err;
 	gint	res;
-	
+
 	sql = sqlite3_mprintf ("BEGIN");
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		g_warning ("Transaction begin failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
 }
 
 static void
-db_end_transaction (void) 
+db_end_transaction (void)
 {
 	gchar	*sql, *err;
 	gint	res;
-	
+
 	sql = sqlite3_mprintf ("END");
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		g_warning ("Transaction end failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
@@ -187,20 +187,20 @@ db_vacuum (void)
 	sqlite3_stmt	*stmt;
 	gint		res, page_count, freelist_count;
 
-	/* Determine fragmentation ratio using 
+	/* Determine fragmentation ratio using
 
 		PRAGMA page_count
 		PRAGMA freelist_count
 
 	   as suggested by adriatic in this blog post
-	   http://jeff.ecchi.ca/blog/2011/12/24/investigating-lifereas-startup-performance/#comment-19989	
+	   http://jeff.ecchi.ca/blog/2011/12/24/investigating-lifereas-startup-performance/#comment-19989
 	   and perform VACUUM only when needed.
 	 */
 
 	db_prepare_stmt (&stmt, "PRAGMA page_count");
 	sqlite3_reset (stmt);
 	res = sqlite3_step (stmt);
-	if (SQLITE_ROW != res) 
+	if (SQLITE_ROW != res)
 		g_error ("Could not determine page count (error code %d)!", res);
 	page_count = sqlite3_column_int (stmt, 0);
 	sqlite3_finalize (stmt);
@@ -208,20 +208,20 @@ db_vacuum (void)
 	db_prepare_stmt (&stmt, "PRAGMA freelist_count");
 	sqlite3_reset (stmt);
 	res = sqlite3_step (stmt);
-	if (SQLITE_ROW != res) 
+	if (SQLITE_ROW != res)
 		g_error ("Could not determine free list count (error code %d)!", res);
 	freelist_count = sqlite3_column_int (stmt, 0);
 	sqlite3_finalize (stmt);
 
 	float fragmentation = (100 * (float)freelist_count/page_count);
 	if (fragmentation > VACUUM_ON_FRAGMENTATION_RATIO) {
-		debug2 (DEBUG_DB, "Performing VACUUM as freelist count/page count ratio %2.2f > %d", 
+		debug2 (DEBUG_DB, "Performing VACUUM as freelist count/page count ratio %2.2f > %d",
 		                  fragmentation, VACUUM_ON_FRAGMENTATION_RATIO);
 		debug_start_measurement (DEBUG_DB);
 		db_exec ("VACUUM;");
 		debug_end_measurement (DEBUG_DB, "VACUUM");
 	} else {
-		debug2 (DEBUG_DB, "No VACUUM as freelist count/page count ratio %2.2f <= %d", 
+		debug2 (DEBUG_DB, "No VACUUM as freelist count/page count ratio %2.2f <= %d",
 		                  fragmentation, VACUUM_ON_FRAGMENTATION_RATIO);
 	}
 }
@@ -253,12 +253,12 @@ void
 db_init (void)
 {
 	gint		res;
-		
+
 	debug_enter ("db_init");
 
 	db_open ();
 
-	/* create info table/check versioning info */				   
+	/* create info table/check versioning info */
 	debug1 (DEBUG_DB, "current DB schema version: %d", db_get_schema_version ());
 
 	if (-1 == db_get_schema_version ()) {
@@ -270,7 +270,7 @@ db_init (void)
 	if (SCHEMA_TARGET_VERSION < db_get_schema_version ())
 		g_error ("Fatal: The cache database was created by a newer version of Liferea than this one!");
 
-	if (SCHEMA_TARGET_VERSION > db_get_schema_version ()) {		
+	if (SCHEMA_TARGET_VERSION > db_get_schema_version ()) {
 		/* do table migration */
 		if (db_get_schema_version () < 5)
 			g_error ("This version of Liferea doesn't support migrating from such an old DB file!");
@@ -284,7 +284,7 @@ db_init (void)
 		}
 
 		if (db_get_schema_version () == 5) {
-				/* 1.4.9 -> 1.4.10 adding parent_item_id to itemset relation */
+			/* 1.4.9 -> 1.4.10 adding parent_item_id to itemset relation */
 			debug0 (DEBUG_DB, "migrating from schema version 5 to 6 (this drops all comments)");
 			db_exec ("BEGIN; "
 			         "DELETE FROM itemsets WHERE comment = 1; "
@@ -329,7 +329,7 @@ db_init (void)
 				 "REPLACE INTO info (name, value) VALUES ('schemaVersion',7); "
 				 "END;");
 		}
-		
+
 		if (db_get_schema_version () == 7) {
 			/* 1.7.1 -> 1.7.2 dropping the itemsets and attention_stats relation */
 			db_exec ("BEGIN; "
@@ -380,7 +380,7 @@ db_init (void)
 		if (db_get_schema_version () == 8) {
 			gchar *sql;
 			sqlite3_stmt *stmt;
-			
+
 			/* 1.7.3 -> 1.7.4 change search folder handling */
 			db_exec ("BEGIN; "
 			         "DROP TABLE view_state; "
@@ -392,7 +392,7 @@ db_init (void)
 				 ");"
 			         "REPLACE INTO info (name, value) VALUES ('schemaVersion',9); "
 			         "END;" );
-			         
+
 			debug0 (DEBUG_DB, "Removing all views.");
 			sql = sqlite3_mprintf("SELECT name FROM sqlite_master WHERE type='view';");
 			res = sqlite3_prepare_v2 (db, sql, -1, &stmt, NULL);
@@ -405,13 +405,13 @@ db_init (void)
 					while (sqlite3_step (stmt) == SQLITE_ROW) {
 						const gchar *viewName = sqlite3_column_text (stmt, 0) + strlen("view_");
 						gchar *copySql = g_strdup_printf("INSERT INTO search_folder_items (node_id, item_id) SELECT '%s',item_id FROM view_%s;", viewName, viewName);
-						
+
 						db_exec (copySql);
 						db_view_remove (viewName);
-						
+
 						g_free (copySql);
 					}
-			
+
 				sqlite3_finalize (stmt);
 			}
 		}
@@ -435,13 +435,13 @@ db_init (void)
 
 	if (SCHEMA_TARGET_VERSION != db_get_schema_version ())
 		g_error ("Fatal: DB schema version not up-to-date! Running with --debug-db could give some hints about the problem!");
-	
+
 	/* Vacuuming... */
 
 	db_vacuum ();
-	
+
 	/* Schema creation */
-		
+
 	debug_start_measurement (DEBUG_DB);
 	db_begin_transaction ();
 
@@ -472,7 +472,7 @@ db_init (void)
 	db_exec ("CREATE INDEX items_idx4 ON items (item_id);");
 	db_exec ("CREATE INDEX items_idx5 ON items (parent_item_id);");
 	db_exec ("CREATE INDEX items_idx6 ON items (parent_node_id);");
-		
+
 	db_exec ("CREATE TABLE metadata ("
         	 "   item_id		INTEGER,"
         	 "   nr              	INTEGER,"
@@ -482,7 +482,7 @@ db_init (void)
         	 ");");
 
 	db_exec ("CREATE INDEX metadata_idx ON metadata (item_id);");
-		
+
 	db_exec ("CREATE TABLE subscription ("
         	 "   node_id            STRING,"
 		 "   source             STRING,"
@@ -526,13 +526,13 @@ db_init (void)
 
 	db_end_transaction ();
 	debug_end_measurement (DEBUG_DB, "table setup");
-		
+
 	/* 2. Removing old triggers */
 	db_exec ("DROP TRIGGER item_insert;");
 	db_exec ("DROP TRIGGER item_update;");
 	db_exec ("DROP TRIGGER item_removal;");
 	db_exec ("DROP TRIGGER subscription_removal;");
-		
+
 	/* 3. Cleanup of DB */
 
 	/* Note: do not check on subscriptions here, as non-subscription node
@@ -540,7 +540,7 @@ db_init (void)
 	debug0 (DEBUG_DB, "Checking for items without a feed list node...\n");
 	db_exec ("DELETE FROM items WHERE comment = 0 AND node_id NOT IN "
         	 "(SELECT node_id FROM node);");
-        	 
+
         debug0 (DEBUG_DB, "Checking for comments without parent item...\n");
 	db_exec ("BEGIN; "
 	         "   CREATE TEMP TABLE tmp_id ( id );"
@@ -549,7 +549,7 @@ db_init (void)
 	         "   DELETE FROM items WHERE item_id IN (SELECT id FROM tmp_id LIMIT 1000);"
 	         "   DROP TABLE tmp_id;"
 		 "END;");
-        
+
 	debug0 (DEBUG_DB, "Checking for search folder items without a feed list node...\n");
 	db_exec ("DELETE FROM search_folder_items WHERE parent_node_id NOT IN "
         	 "(SELECT node_id FROM node);");
@@ -570,7 +570,7 @@ db_init (void)
 		 "(SELECT item_id FROM items);");
 
 	debug0 (DEBUG_DB, "DB cleanup finished. Continuing startup.");
-		
+
 	/* 4. Creating triggers (after cleanup so it is not slowed down by triggers) */
 
 	/* This trigger does explicitely not remove comments! */
@@ -579,7 +579,7 @@ db_init (void)
 		 "   DELETE FROM metadata WHERE item_id = old.item_id; "
 		 "   DELETE FROM search_folder_items WHERE item_id = old.item_id; "
         	 "END;");
-		
+
 	db_exec ("CREATE TRIGGER subscription_removal DELETE ON subscription "
         	 "BEGIN "
 		 "   DELETE FROM node WHERE node_id = old.node_id; "
@@ -587,26 +587,26 @@ db_init (void)
 		 "   DELETE FROM search_folder_items WHERE parent_node_id = old.node_id; "
         	 "END;");
 
-	/* Note: view counting triggers are set up in the view preparation code (see db_view_create()) */		
+	/* Note: view counting triggers are set up in the view preparation code (see db_view_create()) */
 	/* prepare statements */
-	
+
 	db_new_statement ("itemsetLoadStmt",
 	                  "SELECT item_id FROM items WHERE node_id = ?");
 
 	db_new_statement ("itemsetLoadOffsetStmt",
 			  "SELECT item_id FROM items WHERE comment = 0 LIMIT ? OFFSET ?");
-		       
+
 	db_new_statement ("itemsetReadCountStmt",
 	                  "SELECT COUNT(item_id) FROM items "
 		          "WHERE read = 0 AND node_id = ?");
-	       
+
 	db_new_statement ("itemsetItemCountStmt",
 	                  "SELECT COUNT(item_id) FROM items "
 		          "WHERE node_id = ?");
-		       
+
 	db_new_statement ("itemsetRemoveStmt",
 	                  "DELETE FROM items WHERE item_id = ? OR (comment = 1 AND parent_item_id = ?)");
-			
+
 	db_new_statement ("itemsetRemoveAllStmt",
 	                  "DELETE FROM items WHERE node_id = ? OR (comment = 1 AND parent_node_id = ?)");
 
@@ -631,8 +631,8 @@ db_init (void)
 			  "parent_item_id, "
 		          "node_id, "
 			  "parent_node_id "
-	                  " FROM items WHERE item_id = ?");      
-	
+	                  " FROM items WHERE item_id = ?");
+
 	db_new_statement ("itemUpdateStmt",
 	                  "REPLACE INTO items ("
 	                  "title,"
@@ -652,27 +652,27 @@ db_init (void)
 	                  "node_id,"
 	                  "parent_node_id"
 	                  ") values (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)");
-			
+
 	db_new_statement ("itemStateUpdateStmt",
 			  "UPDATE items SET read=?, marked=?, updated=? "
 			  "WHERE item_id=?");
 
 	db_new_statement ("duplicatesFindStmt",
 	                  "SELECT item_id FROM items WHERE source_id = ?");
-			 
+
 	db_new_statement ("duplicateNodesFindStmt",
 	                  "SELECT node_id FROM items WHERE item_id IN "
 			  "(SELECT item_id FROM items WHERE source_id = ?)");
-		       
+
 	db_new_statement ("duplicatesMarkReadStmt",
  	                  "UPDATE items SET read = 1, updated = 0 WHERE source_id = ?");
-						
+
 	db_new_statement ("metadataLoadStmt",
 	                  "SELECT key,value,nr FROM metadata WHERE item_id = ? ORDER BY nr");
-			
+
 	db_new_statement ("metadataUpdateStmt",
 	                  "REPLACE INTO metadata (item_id,nr,key,value) VALUES (?,?,?,?)");
-			
+
 	db_new_statement ("subscriptionUpdateStmt",
 	                  "REPLACE INTO subscription ("
 			  "node_id,"
@@ -684,10 +684,10 @@ db_init (void)
 			  "discontinued,"
 			  "available"
 			  ") VALUES (?,?,?,?,?,?,?,?)");
-			 
+
 	db_new_statement ("subscriptionRemoveStmt",
 	                  "DELETE FROM subscription WHERE node_id = ?");
-			 
+
 	db_new_statement ("subscriptionLoadStmt",
 	                  "SELECT "
 			  "node_id,"
@@ -699,58 +699,61 @@ db_init (void)
 			  "discontinued,"
 			  "available "
 			  "FROM subscription");
-	
+
 	db_new_statement ("subscriptionMetadataLoadStmt",
 	                  "SELECT key,value,nr FROM subscription_metadata WHERE node_id = ? ORDER BY nr");
-			
+
 	db_new_statement ("subscriptionMetadataUpdateStmt",
 	                  "REPLACE INTO subscription_metadata (node_id,nr,key,value) VALUES (?,?,?,?)");
-	
+
 	db_new_statement ("nodeUpdateStmt",
 	                  "REPLACE INTO node (node_id,parent_id,title,type,expanded,view_mode,sort_column,sort_reversed) VALUES (?,?,?,?,?,?,?,?)");
-	                  
+
 	db_new_statement ("itemUpdateSearchFoldersStmt",
 	                  "REPLACE INTO search_folder_items (node_id, parent_node_id, item_id) VALUES (?,?,?)");
 
 	db_new_statement ("itemRemoveFromSearchFolderStmt",
 	                  "DELETE FROM search_folder_items WHERE node_id =? AND item_id = ?;");
-	                  
+
 	db_new_statement ("searchFolderLoadStmt",
 	                  "SELECT item_id FROM search_folder_items WHERE node_id = ?;");
 
 	db_new_statement ("searchFolderCountStmt",
 	                  "SELECT count(item_id) FROM search_folder_items WHERE node_id = ?;");
 
+	db_new_statement ("searchFolderUnreadCountStmt",
+	                  "SELECT count(items.item_id) FROM search_folder_items JOIN items ON search_folder_items.item_id = items.item_id WHERE search_folder_items.node_id = ? and items.read = 0;");
+
 	db_new_statement ("nodeIdListStmt",
 	                  "SELECT node_id FROM node;");
 
 	db_new_statement ("nodeRemoveStmt",
 	                  "DELETE FROM node WHERE node_id = ?;");
-			  
+
 	g_assert (sqlite3_get_autocommit (db));
-	
+
 	debug_exit ("db_init");
 }
 
 void
-db_deinit (void) 
+db_deinit (void)
 {
 
 	debug_enter ("db_deinit");
-	
+
 	if (FALSE == sqlite3_get_autocommit (db))
 		g_warning ("Fatal: DB not in auto-commit mode. This is a bug. Data may be lost!");
-	
+
 	if (statements) {
-		g_hash_table_destroy (statements);	
+		g_hash_table_destroy (statements);
 		statements = NULL;
 	}
-		
+
 	if (SQLITE_OK != sqlite3_close (db))
 		g_warning ("DB close failed: %s", sqlite3_errmsg (db));
-	
+
 	db = NULL;
-	
+
 	debug_exit ("db_deinit");
 }
 
@@ -766,7 +769,7 @@ db_metadata_list_append (GSList *metadata, const char *key, const char *value)
 }
 
 static GSList *
-db_item_metadata_load(itemPtr item) 
+db_item_metadata_load(itemPtr item)
 {
 	GSList		*metadata = NULL;
 	sqlite3_stmt 	*stmt;
@@ -783,7 +786,7 @@ db_item_metadata_load(itemPtr item)
 		value = (const char *) sqlite3_column_text(stmt, 1);
 		if (g_str_equal (key, "enclosure"))
 			item->hasEnclosure = TRUE;
-		metadata = db_metadata_list_append (metadata, key, value); 
+		metadata = db_metadata_list_append (metadata, key, value);
 	}
 
 	sqlite3_finalize (stmt);
@@ -795,7 +798,7 @@ static void
 db_item_metadata_update_cb (const gchar *key,
                             const gchar *value,
                             guint index,
-                            gpointer user_data) 
+                            gpointer user_data)
 {
 	sqlite3_stmt	*stmt;
 	itemPtr		item = (itemPtr)user_data;
@@ -807,7 +810,7 @@ db_item_metadata_update_cb (const gchar *key,
 	sqlite3_bind_text (stmt, 3, key, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 4, value, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
-	if (SQLITE_DONE != res) 
+	if (SQLITE_DONE != res)
 		g_warning ("Update in \"metadata\" table failed (error code=%d, %s)", res, sqlite3_errmsg (db));
 
 	sqlite3_finalize (stmt);
@@ -815,7 +818,7 @@ db_item_metadata_update_cb (const gchar *key,
 }
 
 static void
-db_item_metadata_update(itemPtr item) 
+db_item_metadata_update(itemPtr item)
 {
 	metadata_list_foreach(item->metadata, db_item_metadata_update_cb, item);
 }
@@ -823,12 +826,12 @@ db_item_metadata_update(itemPtr item)
 /* Item structure loading methods */
 
 static itemPtr
-db_load_item_from_columns (sqlite3_stmt *stmt) 
+db_load_item_from_columns (sqlite3_stmt *stmt)
 {
 	const gchar	*tmp;
 
 	itemPtr item = item_new ();
-	
+
 	item->readStatus	= sqlite3_column_int (stmt, 1)?TRUE:FALSE;
 	item->updateStatus	= sqlite3_column_int (stmt, 2)?TRUE:FALSE;
 	item->popupStatus	= sqlite3_column_int (stmt, 3)?TRUE:FALSE;
@@ -844,11 +847,11 @@ db_load_item_from_columns (sqlite3_stmt *stmt)
 
 	item->title		= g_strdup ((const gchar *) sqlite3_column_text(stmt, 0));
 	item->sourceId		= g_strdup ((const gchar *) sqlite3_column_text(stmt, 6));
-	
+
 	tmp = (const gchar *) sqlite3_column_text(stmt, 5);
 	if (tmp)
 		item->source = g_strdup (tmp);
-		
+
 	tmp = (const gchar *) sqlite3_column_text(stmt, 8);
 	if (tmp)
 		item->description = g_strdup (tmp);
@@ -861,7 +864,7 @@ db_load_item_from_columns (sqlite3_stmt *stmt)
 }
 
 itemSetPtr
-db_itemset_load (const gchar *id) 
+db_itemset_load (const gchar *id)
 {
 	sqlite3_stmt	*stmt;
 	itemSetPtr 	itemSet;
@@ -880,19 +883,19 @@ db_itemset_load (const gchar *id)
 	sqlite3_finalize (stmt);
 
 	debug0 (DEBUG_DB, "loading of itemset finished");
-	
+
 	return itemSet;
 }
 
 itemPtr
-db_item_load (gulong id) 
+db_item_load (gulong id)
 {
 	sqlite3_stmt	*stmt;
 	itemPtr 	item = NULL;
 
 	debug1 (DEBUG_DB, "loading item %lu", id);
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("itemLoadStmt");
 	sqlite3_bind_int (stmt, 1, id);
 
@@ -902,7 +905,7 @@ db_item_load (gulong id)
 	} else {
 		debug1 (DEBUG_DB, "Could not load item with id %lu!", id);
 	}
-	
+
 	sqlite3_finalize (stmt);
 
 	debug_end_measurement (DEBUG_DB, "item load");
@@ -912,45 +915,6 @@ db_item_load (gulong id)
 
 /* Item modification methods */
 
-static int
-db_item_set_id_cb (void *user_data,
-                   int count,
-		   char **values,
-		   char **columns) 
-{
-	itemPtr	item = (itemPtr)user_data;
-	
-	g_assert(NULL != values);
-
-	if(values[0]) {
-		/* the result in *values should be MAX(item_id),
-		   so adding one should give a unique new id */
-		item->id = 1 + atol(values[0]); 
-	} else {
-		/* empty table causes no result in values[0]... */
-		item->id = 1;
-	}
-	
-	debug2(DEBUG_DB, "new item id=%lu for \"%s\"", item->id, item->title);
-	return 0;
-}
-
-static void
-db_item_set_id (itemPtr item) 
-{
-	gchar	*sql, *err;
-	gint	res;
-	
-	g_assert (0 == item->id);
-	
-	sql = sqlite3_mprintf ("SELECT MAX(item_id) FROM items");
-	res = sqlite3_exec (db, sql, db_item_set_id_cb, item, &err);
-	if (SQLITE_OK != res) 
-		g_warning ("Select failed (%s) SQL: %s", err, sql);
-	sqlite3_free (sql);
-	sqlite3_free (err);
-}
-
 static void
 db_item_search_folders_update (itemPtr item)
 {
@@ -961,7 +925,7 @@ db_item_search_folders_update (itemPtr item)
 	/* Bail on comments which are not covered by search folders */
 	if (item->isComment)
 		return;
-	
+
 	/* Add item to all search folders it now belongs to */
 
 	stmt = db_get_statement ("itemUpdateSearchFoldersStmt");
@@ -974,7 +938,7 @@ db_item_search_folders_update (itemPtr item)
 		sqlite3_bind_int (stmt, 3, item->id);
 		res = sqlite3_step (stmt);
 
-		if (SQLITE_DONE != res) 
+		if (SQLITE_DONE != res)
 			g_warning ("item add to search folder failed (error code=%d, %s)", res, sqlite3_errmsg (db));
 		iter = g_slist_next (iter);
 
@@ -995,7 +959,7 @@ db_item_search_folders_update (itemPtr item)
 		sqlite3_bind_int (stmt, 2, item->id);
 		res = sqlite3_step (stmt);
 
-		if (SQLITE_DONE != res) 
+		if (SQLITE_DONE != res)
 			g_warning ("item remove from search folder failed (error code=%d, %s)", res, sqlite3_errmsg (db));
 		iter = g_slist_next (iter);
 
@@ -1006,22 +970,16 @@ db_item_search_folders_update (itemPtr item)
 }
 
 void
-db_item_update (itemPtr item) 
+db_item_update (itemPtr item)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug2 (DEBUG_DB, "update of item \"%s\" (id=%lu)", item->title, item->id);
 	debug_start_measurement (DEBUG_DB);
-	
+
 	db_begin_transaction ();
 
-	if (!item->id) {
-		db_item_set_id (item);
-
-		debug1(DEBUG_DB, "insert into table \"items\": \"%s\"", item->title);	
-	}
-
 	/* Update the item... */
 	stmt = db_get_statement ("itemUpdateStmt");
 	sqlite3_bind_text (stmt, 1,  item->title, -1, SQLITE_TRANSIENT);
@@ -1036,15 +994,22 @@ db_item_update (itemPtr item)
 	sqlite3_bind_int64  (stmt, 10, item->time);
 	sqlite3_bind_text (stmt, 11, item->commentFeedId, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_int  (stmt, 12, item->isComment?1:0);
-	sqlite3_bind_int  (stmt, 13, item->id);
+	if (item->id)
+		sqlite3_bind_int  (stmt, 13, item->id);
+	else
+		sqlite3_bind_null (stmt, 13);
 	sqlite3_bind_int  (stmt, 14, item->parentItemId);
 	sqlite3_bind_text (stmt, 15, item->nodeId, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 16, item->parentNodeId, -1, SQLITE_TRANSIENT);
 
 	res = sqlite3_step (stmt);
 
-	if (SQLITE_DONE != res) 
+	if (SQLITE_DONE != res)
 		g_warning ("item update failed (error code=%d, %s)", res, sqlite3_errmsg (db));
+	if (!item->id && SQLITE_DONE == res) {
+		item->id = sqlite3_last_insert_rowid (db);
+		debug2(DEBUG_DB, "insert into table \"items\": \"%s\" id : %lu", item->title, item->id);
+	}
 
 	sqlite3_finalize (stmt);
 
@@ -1060,7 +1025,7 @@ void
 db_item_state_update (itemPtr item)
 {
 	sqlite3_stmt	*stmt;
-	
+
 	if (!item->id) {
 		db_item_update (item);
 		return;
@@ -1069,16 +1034,16 @@ db_item_state_update (itemPtr item)
 	db_item_search_folders_update (item);
 
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("itemStateUpdateStmt");
 	sqlite3_bind_int (stmt, 1, item->readStatus?1:0);
 	sqlite3_bind_int (stmt, 2, item->flagStatus?1:0);
 	sqlite3_bind_int (stmt, 3, item->updateStatus?1:0);
 	sqlite3_bind_int (stmt, 4, item->id);
 
-	if (sqlite3_step (stmt) != SQLITE_DONE) 
+	if (sqlite3_step (stmt) != SQLITE_DONE)
 		g_warning ("item state update failed (%s)", sqlite3_errmsg (db));
-	
+
 	sqlite3_finalize (stmt);
 
 	debug_end_measurement (DEBUG_DB, "item state update");
@@ -1086,13 +1051,13 @@ db_item_state_update (itemPtr item)
 }
 
 void
-db_item_remove (gulong id) 
+db_item_remove (gulong id)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug1 (DEBUG_DB, "removing item with id %lu", id);
-	
+
 	stmt = db_get_statement ("itemsetRemoveStmt");
 	sqlite3_bind_int (stmt, 1, id);
 	sqlite3_bind_int (stmt, 2, id);
@@ -1104,8 +1069,8 @@ db_item_remove (gulong id)
 	sqlite3_finalize (stmt);
 }
 
-GSList * 
-db_item_get_duplicates (const gchar *guid) 
+GSList *
+db_item_get_duplicates (const gchar *guid)
 {
 	GSList		*duplicates = NULL;
 	sqlite3_stmt	*stmt;
@@ -1118,7 +1083,7 @@ db_item_get_duplicates (const gchar *guid)
 	if (SQLITE_OK != res)
 		g_error ("db_item_get_duplicates: sqlite bind failed (error code %d)!", res);
 
-	while (sqlite3_step (stmt) == SQLITE_ROW) 
+	while (sqlite3_step (stmt) == SQLITE_ROW)
 	{
 		gulong id = sqlite3_column_int (stmt, 0);
 		duplicates = g_slist_append (duplicates, GUINT_TO_POINTER (id));
@@ -1145,7 +1110,7 @@ db_item_get_duplicate_nodes (const gchar *guid)
 	if (SQLITE_OK != res)
 		g_error ("db_item_get_duplicates: sqlite bind failed (error code %d)!", res);
 
-	while (sqlite3_step (stmt) == SQLITE_ROW) 
+	while (sqlite3_step (stmt) == SQLITE_ROW)
 	{
 		gchar *id = g_strdup((const gchar *) sqlite3_column_text (stmt, 0));
 		duplicates = g_slist_append (duplicates, id);
@@ -1158,14 +1123,14 @@ db_item_get_duplicate_nodes (const gchar *guid)
 	return duplicates;
 }
 
-void 
-db_itemset_remove_all (const gchar *id) 
+void
+db_itemset_remove_all (const gchar *id)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug1(DEBUG_DB, "removing all items for item set with %s", id);
-		
+
 	stmt = db_get_statement ("itemsetRemoveAllStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 2, id, -1, SQLITE_TRANSIENT);
@@ -1178,14 +1143,14 @@ db_itemset_remove_all (const gchar *id)
 
 }
 
-void 
-db_itemset_mark_all_popup (const gchar *id) 
+void
+db_itemset_mark_all_popup (const gchar *id)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug1 (DEBUG_DB, "marking all items popup for item set with %s", id);
-		
+
 	stmt = db_get_statement ("itemsetMarkAllPopupStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
@@ -1221,24 +1186,24 @@ db_itemset_get (itemSetPtr itemSet, gulong offset, guint limit)
 
 /* Statistics interface */
 
-guint 
-db_itemset_get_unread_count (const gchar *id) 
+guint
+db_itemset_get_unread_count (const gchar *id)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
 	guint		count = 0;
-	
+
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("itemsetReadCountStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
-	
+
 	if (SQLITE_ROW == res)
 		count = sqlite3_column_int (stmt, 0);
 	else
 		g_warning("item read counting failed (error code=%d, %s)", res, sqlite3_errmsg (db));
-		
+
 	sqlite3_finalize (stmt);
 
 	debug_end_measurement (DEBUG_DB, "counting unread items");
@@ -1246,19 +1211,19 @@ db_itemset_get_unread_count (const gchar *id)
 	return count;
 }
 
-guint 
-db_itemset_get_item_count (const gchar *id) 
+guint
+db_itemset_get_item_count (const gchar *id)
 {
 	sqlite3_stmt 	*stmt;
 	gint		res;
 	guint		count = 0;
 
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("itemsetItemCountStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
-	
+
 	if (SQLITE_ROW == res)
 		count = sqlite3_column_int (stmt, 0);
 	else
@@ -1277,11 +1242,11 @@ db_view_remove_triggers (const gchar *id)
 {
 	gchar	*sql, *err;
 	gint	res;
-	
+
 	err = NULL;
 	sql = sqlite3_mprintf ("DROP TRIGGER view_%s_insert_before;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		debug2 (DEBUG_DB, "Dropping trigger failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
@@ -1289,34 +1254,34 @@ db_view_remove_triggers (const gchar *id)
 	err = NULL;
 	sql = sqlite3_mprintf ("DROP TRIGGER view_%s_insert_after;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		debug2 (DEBUG_DB, "Dropping trigger failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
-	
+
 	err = NULL;
 	sql = sqlite3_mprintf ("DROP TRIGGER view_%s_delete;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		debug2 (DEBUG_DB, "Dropping trigger failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
-	
+
 	err = NULL;
 	sql = sqlite3_mprintf ("DROP TRIGGER view_%s_update_before;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		debug2 (DEBUG_DB, "Dropping trigger failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
 	sqlite3_free (err);
-	
+
 	err = NULL;
 	sql = sqlite3_mprintf ("DROP TRIGGER view_%s_update_after;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		debug2 (DEBUG_DB, "Dropping trigger failed (%s) SQL: %s", err, sql);
 	sqlite3_free (sql);
-	sqlite3_free (err);	
+	sqlite3_free (err);
 }
 
 /* This method is only used for migration from old schema versions */
@@ -1325,26 +1290,26 @@ db_view_remove (const gchar *id)
 {
 	gchar	*sql, *err;
 	gint	res;
-	
+
 	debug1 (DEBUG_DB, "Dropping view \"%s\"", id);
-	
+
 	db_view_remove_triggers (id);
 
 	/* Note: no need to remove anything from view_state, as this
 	   is dropped on schema migration and this method is only
-	   used during schema migration to remove all views. */	
-		
-	sql = sqlite3_mprintf ("DROP VIEW view_%s;", id);	
+	   used during schema migration to remove all views. */
+
+	sql = sqlite3_mprintf ("DROP VIEW view_%s;", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
-	if (SQLITE_OK != res) 
+	if (SQLITE_OK != res)
 		g_warning ("Dropping view failed (%s) SQL: %s", err, sql);
-	
+
 	sqlite3_free (sql);
 	sqlite3_free (err);
 }
 
 itemSetPtr
-db_search_folder_load (const gchar *id) 
+db_search_folder_load (const gchar *id)
 {
 	gint		res;
 	sqlite3_stmt	*stmt;
@@ -1356,14 +1321,14 @@ db_search_folder_load (const gchar *id)
 	res = sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	if (SQLITE_OK != res)
 		g_error ("db_search_folder_load: sqlite bind failed (error code %d)!", res);
-	
+
 	itemSet = g_new0 (struct itemSet, 1);
 	itemSet->nodeId = (gchar *)id;
 
 	while (sqlite3_step (stmt) == SQLITE_ROW) {
 		itemSet->ids = g_list_append (itemSet->ids, GUINT_TO_POINTER (sqlite3_column_int (stmt, 0)));
 	}
-	
+
 	sqlite3_finalize (stmt);
 
 	debug1 (DEBUG_DB, "loading search folder finished (%d items)", g_list_length (itemSet->ids));
@@ -1372,13 +1337,13 @@ db_search_folder_load (const gchar *id)
 }
 
 void
-db_search_folder_reset (const gchar *id) 
+db_search_folder_reset (const gchar *id)
 {
 	gchar	*sql, *err;
 	gint	res;
 
 	debug1 (DEBUG_DB, "resetting search folder node \"%s\"", id);
-	
+
 	sql = sqlite3_mprintf ("DELETE FROM search_folder_items WHERE node_id = '%s';", id);
 	res = sqlite3_exec (db, sql, NULL, NULL, &err);
 	if (SQLITE_OK != res)
@@ -1386,7 +1351,7 @@ db_search_folder_reset (const gchar *id)
 
 	sqlite3_free (sql);
 	sqlite3_free (err);
-	
+
 	debug0 (DEBUG_DB, "removing search folder finished");
 }
 
@@ -1400,7 +1365,7 @@ db_search_folder_add_items (const gchar *id, GSList *items)
 	debug2 (DEBUG_DB, "add %d items to search folder node \"%s\"", g_slist_length (items), id);
 
 	stmt = db_get_statement ("itemUpdateSearchFoldersStmt");
-	
+
 	iter = items;
 	while (iter) {
 		itemPtr item = (itemPtr)iter->data;
@@ -1422,24 +1387,49 @@ db_search_folder_add_items (const gchar *id, GSList *items)
 	debug0 (DEBUG_DB, "adding items to search folder finished");
 }
 
-guint 
-db_search_folder_get_item_count (const gchar *id) 
+guint
+db_search_folder_get_item_count (const gchar *id)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
 	guint		count = 0;
-	
+
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("searchFolderCountStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
-	
+
 	if (SQLITE_ROW == res)
 		count = sqlite3_column_int (stmt, 0);
 	else
 		g_warning("item read counting failed (error code=%d, %s)", res, sqlite3_errmsg (db));
-		
+
+	sqlite3_finalize (stmt);
+
+	debug_end_measurement (DEBUG_DB, "counting unread items");
+
+	return count;
+}
+
+guint
+db_search_folder_get_unread_count (const gchar *id)
+{
+	sqlite3_stmt	*stmt;
+	gint		res;
+	guint		count = 0;
+
+	debug_start_measurement (DEBUG_DB);
+
+	stmt = db_get_statement ("searchFolderUnreadCountStmt");
+	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
+	res = sqlite3_step (stmt);
+
+	if (SQLITE_ROW == res)
+		count = sqlite3_column_int (stmt, 0);
+	else
+		g_warning("item unread counting failed (error code=%d, %s)", res, sqlite3_errmsg (db));
+
 	sqlite3_finalize (stmt);
 
 	debug_end_measurement (DEBUG_DB, "counting unread items");
@@ -1448,7 +1438,7 @@ db_search_folder_get_item_count (const gchar *id)
 }
 
 static GSList *
-db_subscription_metadata_load (const gchar *id) 
+db_subscription_metadata_load (const gchar *id)
 {
 	GSList		*metadata = NULL;
 	sqlite3_stmt	*stmt;
@@ -1460,7 +1450,7 @@ db_subscription_metadata_load (const gchar *id)
 		g_error ("db_subscription_metadata_load: sqlite bind failed (error code %d)!", res);
 
 	while (sqlite3_step (stmt) == SQLITE_ROW) {
-		metadata = db_metadata_list_append (metadata, (const char *) sqlite3_column_text(stmt, 0), 
+		metadata = db_metadata_list_append (metadata, (const char *) sqlite3_column_text(stmt, 0),
 		                                           (const char *) sqlite3_column_text(stmt, 1));
 	}
 
@@ -1473,7 +1463,7 @@ static void
 db_subscription_metadata_update_cb (const gchar *key,
                                     const gchar *value,
                                     guint index,
-                                    gpointer user_data) 
+                                    gpointer user_data)
 {
 	sqlite3_stmt	*stmt;
 	nodePtr		node = (nodePtr)user_data;
@@ -1485,14 +1475,14 @@ db_subscription_metadata_update_cb (const gchar *key,
 	sqlite3_bind_text (stmt, 3, key, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 4, value, -1, SQLITE_TRANSIENT);
 	res = sqlite3_step (stmt);
-	if (SQLITE_DONE != res) 
+	if (SQLITE_DONE != res)
 		g_warning ("Update in \"subscription_metadata\" table failed (error code=%d, %s)", res, sqlite3_errmsg (db));
 
 	sqlite3_finalize (stmt);
 }
 
 static void
-db_subscription_metadata_update (subscriptionPtr subscription) 
+db_subscription_metadata_update (subscriptionPtr subscription)
 {
 	metadata_list_foreach (subscription->metadata, db_subscription_metadata_update_cb, subscription->node);
 }
@@ -1508,14 +1498,14 @@ db_subscription_update (subscriptionPtr subscription)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug1 (DEBUG_DB, "updating subscription info %s", subscription->node->id);
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("subscriptionUpdateStmt");
 	sqlite3_bind_text (stmt, 1, subscription->node->id, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 2, subscription->source, -1, SQLITE_TRANSIENT);
-	sqlite3_bind_text (stmt, 3, subscription->origSource, -1, SQLITE_TRANSIENT);	
+	sqlite3_bind_text (stmt, 3, subscription->origSource, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 4, subscription->filtercmd, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_int  (stmt, 5, subscription->updateInterval);
 	sqlite3_bind_int  (stmt, 6, subscription->defaultInterval);
@@ -1523,15 +1513,15 @@ db_subscription_update (subscriptionPtr subscription)
 	sqlite3_bind_int  (stmt, 8, (subscription->updateError ||
 	                             subscription->httpError ||
 				     subscription->filterError)?1:0);
-	
+
 	res = sqlite3_step (stmt);
 	if (SQLITE_DONE != res)
 		g_warning ("Could not update subscription info for node id %s in DB (error code %d)!", subscription->node->id, res);
-	
+
 	sqlite3_finalize (stmt);
 
 	db_subscription_metadata_update (subscription);
-		
+
 	debug_end_measurement (DEBUG_DB, "subscription update");
 }
 
@@ -1543,7 +1533,7 @@ db_subscription_remove (const gchar *id)
 
 	debug1 (DEBUG_DB, "removing subscription %s", id);
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("subscriptionRemoveStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 
@@ -1561,26 +1551,26 @@ db_node_update (nodePtr node)
 {
 	sqlite3_stmt	*stmt;
 	gint		res;
-	
+
 	debug1 (DEBUG_DB, "updating node info %s", node->id);
 	debug_start_measurement (DEBUG_DB);
-	
+
 	stmt = db_get_statement ("nodeUpdateStmt");
 	sqlite3_bind_text (stmt, 1, node->id, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 2, node->parent->id, -1, SQLITE_TRANSIENT);
-	sqlite3_bind_text (stmt, 3, node->title, -1, SQLITE_TRANSIENT);	
+	sqlite3_bind_text (stmt, 3, node->title, -1, SQLITE_TRANSIENT);
 	sqlite3_bind_text (stmt, 4, node_type_to_str (node), -1, SQLITE_TRANSIENT);
 	sqlite3_bind_int  (stmt, 5, node->expanded?1:0);
 	sqlite3_bind_int  (stmt, 6, node->viewMode);
 	sqlite3_bind_int  (stmt, 7, node->sortColumn);
 	sqlite3_bind_int  (stmt, 8, node->sortReversed?1:0);
-	
+
 	res = sqlite3_step (stmt);
 	if (SQLITE_DONE != res)
 		g_warning ("Could not update node info %s in DB (error code %d)!", node->id, res);
 
 	sqlite3_finalize (stmt);
-		
+
 	debug_end_measurement (DEBUG_DB, "node update");
 }
 
@@ -1608,7 +1598,7 @@ db_node_remove (const gchar *id)
 	sqlite3_stmt	*stmt;
 	gint		res;
 
-	stmt = db_get_statement ("nodeRemoveStmt");	
+	stmt = db_get_statement ("nodeRemoveStmt");
 	sqlite3_bind_text (stmt, 1, id, -1, SQLITE_TRANSIENT);
 
 	res = sqlite3_step (stmt);
