@@ -23,8 +23,8 @@
 
 #include <errno.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 #include <libxml/tree.h>
-#include <sys/stat.h>
 
 #include "auth.h"
 #include "common.h"
@@ -183,8 +183,7 @@ export_OPML_feedlist (const gchar *filename, nodePtr node, gboolean trusted)
 		xmlFreeDoc (doc);
 
 		if (!error) {
-			// FIXME: Use g_rename() once we've reached Glib 2.6+
-			if (rename (backupFilename, filename) < 0) {
+			if (g_rename (backupFilename, filename) < 0) {
 				g_warning (_("Error renaming %s to %s: %s\n"), backupFilename, filename, g_strerror (errno));
 				error = TRUE;
 			}
@@ -348,21 +347,14 @@ import_parse_outline (xmlNodePtr cur, nodePtr parentNode, gboolean trusted)
 	/* 6. do node type specific parsing */
 	NODE_TYPE (node)->import (node, parentNode, cur, trusted);
 
-	if (node->subscription) {
-		/* Handle OPML auth info (imported from subscription_import() */
-		if(node->subscription->updateOptions->username) {
-			/* Write to password store (for migration) */
-			liferea_auth_info_store (node->subscription);
-		} else {
-			/* If no auth options in OPML try to import them from the key store */
-			liferea_auth_info_query (node->id);
-		}
+	if (node->subscription)
+		liferea_auth_info_query (node->id);
 
-		/* 7. update immediately if necessary */
-		if (needsUpdate) {
-			debug1 (DEBUG_CACHE, "seems to be an import, setting new id: %s and doing first download...", node_get_id(node));
-			subscription_update (node->subscription, 0);
-		}
+	/* 7. update immediately if necessary */
+	// FIXME: this should not be done here!!!
+	if (node->subscription && needsUpdate) {
+		debug1 (DEBUG_CACHE, "seems to be an import, setting new id: %s and doing first download...", node_get_id(node));
+		subscription_update (node->subscription, 0);
 	}
 
 	/* 8. Always update the node info in the DB to ensure a proper
