@@ -1,7 +1,7 @@
 /**
  * @file feed_parser.c  parsing of different feed formats
  *
- * Copyright (C) 2008-2020 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2008-2021 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,8 +27,11 @@
 #include "xml.h"
 #include "parsers/atom10.h"
 #include "parsers/html5_feed.h"
+#include "parsers/ldjson_feed.h"
 #include "parsers/rss_channel.h"
 
+#define AUTO_DISCOVERY_MAX_REDIRECTS	5
+
 static GSList *feedHandlers = NULL;	/**< list of available parser implementations */
 
 struct feed_type {
@@ -43,9 +46,11 @@ feed_parsers_get_list (void)
 		return feedHandlers;
 
 	feedHandlers = g_slist_append (feedHandlers, rss_init_feed_handler ());
-	feedHandlers = g_slist_append (feedHandlers, atom10_init_feed_handler ());  /* Must be before pie */
+	feedHandlers = g_slist_append (feedHandlers, atom10_init_feed_handler ());
 
-	// Do not register HTML5 feed parser here, as it is a HTML and not a feed parser
+	/* Order is important ! */
+	feedHandlers = g_slist_append (feedHandlers, ldjson_init_feed_handler ());
+	feedHandlers = g_slist_append (feedHandlers, html5_init_feed_handler ());
 
 	return feedHandlers;
 }
@@ -77,17 +82,22 @@ feed_type_str_to_fhp (const gchar *str)
 }
 
 feedParserCtxtPtr
-feed_create_parser_ctxt (void)
+feed_parser_ctxt_new (subscriptionPtr subscription, const gchar *data, gsize size)
 {
 	feedParserCtxtPtr ctxt;
 
 	ctxt = g_new0 (struct feedParserCtxt, 1);
+	ctxt->subscription = subscription;
+	ctxt->feed = (feedPtr)subscription->node->data;
+	ctxt->data = data;
+	ctxt->dataLength = size;
 	ctxt->tmpdata = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_free);
+
 	return ctxt;
 }
 
 void
-feed_free_parser_ctxt (feedParserCtxtPtr ctxt)
+feed_parser_ctxt_free (feedParserCtxtPtr ctxt)
 {
 	if (ctxt) {
 		/* Don't free the itemset! */
@@ -102,8 +112,6 @@ feed_free_parser_ctxt (feedParserCtxtPtr ctxt)
  * tries to download it. If it finds a valid feed source it parses
  * this source instead into the given feed parsing context. It also
  * replaces the HTTP URI with the found feed source.
- *
- * Mutates ctxt->failed and ctxt->feed->parseErrors
  */
 static gboolean
 feed_parser_auto_discover (feedParserCtxtPtr ctxt)
@@ -111,12 +119,7 @@ feed_parser_auto_discover (feedParserCtxtPtr ctxt)
 	gchar	*source = NULL;
 	GSList	*links;
 
-	if (ctxt->feed->parseErrors)
-		g_string_truncate (ctxt->feed->parseErrors, 0);
-	else
-		ctxt->feed->parseErrors = g_string_new(NULL);
-
-	debug1 (DEBUG_UPDATE, "Starting feed auto discovery (%s)", subscription_get_source (ctxt->subscription));
+	debug2 (DEBUG_UPDATE, "Starting feed auto discovery (%s) redirects=%d", subscription_get_source (ctxt->subscription), ctxt->subscription->autoDiscoveryTries);
 
 	links = html_auto_discover_feed (ctxt->data, subscription_get_source (ctxt->subscription));
 	if (links)
@@ -125,7 +128,6 @@ feed_parser_auto_discover (feedParserCtxtPtr ctxt)
 	/* FIXME: we only need the !g_str_equal as a workaround after a 404 */
 	if (source && !g_str_equal (source, subscription_get_source (ctxt->subscription))) {
 		debug1 (DEBUG_UPDATE, "Discovered link: %s", source);
-		ctxt->failed = FALSE;
 		subscription_set_source (ctxt->subscription, source);
 
 		/* The feed that was processed wasn't the correct one, we need to redownload it.
@@ -133,27 +135,27 @@ feed_parser_auto_discover (feedParserCtxtPtr ctxt)
 		subscription_cancel_update (ctxt->subscription);
 		subscription_update (ctxt->subscription, FEED_REQ_RESET_TITLE);
 		g_free (source);
-	} else {
-		debug0 (DEBUG_UPDATE, "No feed link found!");
-		g_string_append (ctxt->feed->parseErrors, _("The URL you want Liferea to subscribe to points to a webpage and the auto discovery found no feeds on this page. Maybe this webpage just does not support feed auto discovery."));
+
+		return TRUE;
 	}
+
+	debug0 (DEBUG_UPDATE, "No feed link found!");
+	return FALSE;
 }
 
 static void
 feed_parser_ctxt_cleanup (feedParserCtxtPtr ctxt)
 {
 	/* free old temp. parsing data, don't free right after parsing because
-	it can be used until the last feed request is finished, move me
-	to the place where the last request in list otherRequests is
-	finished :-) */
+	   it can be used until the last feed request is finished */
 	g_hash_table_destroy (ctxt->tmpdata);
 	ctxt->tmpdata = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, g_free);
 
 	/* we always drop old metadata */
+	// FIXME: this is bad, doesn't belong here at all
 	metadata_list_free (ctxt->subscription->metadata);
 
 	ctxt->subscription->metadata = NULL;
-	ctxt->failed = FALSE;
 }
 
 /**
@@ -170,109 +172,106 @@ feed_parser_ctxt_cleanup (feedParserCtxtPtr ctxt)
 gboolean
 feed_parse (feedParserCtxtPtr ctxt)
 {
-	xmlNodePtr	cur;
-	gboolean	success = FALSE;
+	xmlNodePtr	xmlNode = NULL, htmlNode = NULL;
+	xmlDocPtr	xmlDoc, htmlDoc;
+	gboolean	autoDiscovery = FALSE, success = FALSE;
 
 	debug_enter ("feed_parse");
 
 	g_assert (NULL == ctxt->items);
 
-	ctxt->failed = TRUE;	/* reset on success ... */
-
 	if (ctxt->feed->parseErrors)
 		g_string_truncate (ctxt->feed->parseErrors, 0);
 	else
 		ctxt->feed->parseErrors = g_string_new (NULL);
 
-	/* 1.) try to parse downloaded data as XML and try to read a feed format */
+	/* Prepare two documents, one parse as XML and one as XHTML.
+	   Depending on the feed parser being an HTML parser the one
+	   or the other is used. */
+
+	/* 1.) try to parse downloaded data as XML */
 	do {
-		if (NULL == xml_parse_feed (ctxt)) {
-			g_string_append_printf (ctxt->feed->parseErrors, _("XML error while reading feed! Feed \"%s\" could not be loaded!"), subscription_get_source (ctxt->subscription));
+		if (NULL == (xmlDoc = xml_parse_feed (ctxt))) {
+			ctxt->subscription->error = FETCH_ERROR_XML;
 			break;
 		}
 
-		if (NULL == (cur = xmlDocGetRootElement(ctxt->doc))) {
-			g_string_append(ctxt->feed->parseErrors, _("Empty document!"));
+		if (NULL == (xmlNode = xmlDocGetRootElement (xmlDoc))) {
+			ctxt->subscription->error = FETCH_ERROR_XML;
+			g_string_append (ctxt->feed->parseErrors, _("Empty document!"));
 			break;
 		}
 
-		while (cur && xmlIsBlankNode(cur)) {
-			cur = cur->next;
+		while (xmlNode && xmlIsBlankNode (xmlNode)) {
+			xmlNode = xmlNode->next;
 		}
 
-		if (!cur)
-			break;
-
-		if (!cur->name) {
-			g_string_append(ctxt->feed->parseErrors, _("Invalid XML!"));
+		if (!xmlNode->name) {
+			g_string_append (ctxt->feed->parseErrors, _("Invalid XML!"));
 			break;
 		}
+	} while (0);
 
-		/* determine the syndication format and start parser */
-		GSList *handlerIter = feed_parsers_get_list ();
-		while(handlerIter) {
-			feedHandlerPtr handler = (feedHandlerPtr)(handlerIter->data);
-			if(handler && handler->checkFormat && (*(handler->checkFormat))(ctxt->doc, cur)) {
-				ctxt->feed->fhp = handler;
-				feed_parser_ctxt_cleanup (ctxt);
-				(*(handler->feedParser)) (ctxt, cur);
-				break;
-			}
-			handlerIter = handlerIter->next;
+	/* 2.) Prepare data as XHTML */
+	do {
+		if (NULL == (htmlDoc = xhtml_parse (ctxt->data, ctxt->dataLength)))
+			break;
+
+		if (NULL == (htmlNode = xmlDocGetRootElement (htmlDoc))) {
+			//g_string_append (ctxt->feed->parseErrors, _("Empty document!"));
+			break;
 		}
-	} while(0);
+	} while (0);
 
+	/* determine the syndication format and start parser with either XML or XHTML doc */
+	GSList *handlerIter = feed_parsers_get_list ();
+	while (handlerIter) {
+		feedHandlerPtr handler = (feedHandlerPtr)(handlerIter->data);
+		xmlNodePtr node = handler->html?htmlNode:xmlNode;
 
-	if (ctxt->doc) {
-		xmlFreeDoc(ctxt->doc);
-		ctxt->doc = NULL;
+		if (node && handler && handler->checkFormat && (*(handler->checkFormat))(node->doc, node)) {
+			ctxt->feed->fhp = handler;
+			feed_parser_ctxt_cleanup (ctxt);
+			(*(handler->feedParser)) (ctxt, handler->html?htmlNode:xmlNode);
+			success = TRUE;
+			break;
+		}
+		handlerIter = handlerIter->next;
 	}
 
-	/* 2.) None of the feed formats did work, chance is high that we are
-           working on a HTML documents. Let's look for feed links inside it! */
-	if (ctxt->failed)
-		feed_parser_auto_discover (ctxt);
-
-	/* 3.) alternatively try to parse the HTML document we are on as HTML5 feed */
-	if (ctxt->failed) {
-		do {
-			if (ctxt->doc = xhtml_parse (ctxt->data, ctxt->dataLength))
-				g_string_truncate (ctxt->feed->parseErrors, 0);
-			else
-				break;
-
-			if (NULL == (cur = xmlDocGetRootElement (ctxt->doc))) {
-				g_string_append(ctxt->feed->parseErrors, _("Empty document!"));
-				break;
-			}
-
-			ctxt->feed->fhp = html5_init_feed_handler ();
-			if ((*(ctxt->feed->fhp->checkFormat)) (ctxt->doc, cur)) {
-					feed_parser_ctxt_cleanup (ctxt);
-					(*(ctxt->feed->fhp->feedParser)) (ctxt, cur);
-			}
-		} while(0);
-	}
-
-	if (ctxt->doc) {
-		xmlFreeDoc(ctxt->doc);
-		ctxt->doc = NULL;
-	}
-
-	/* 4.) We give up and inform the user */
-	if (ctxt->failed) {
-		/* test if we have a HTML page */
-		if((strstr (ctxt->data, "<html>") || strstr (ctxt->data, "<HTML>") ||
-		    strstr (ctxt->data, "<html ") || strstr (ctxt->data, "<HTML "))) {
-			debug0(DEBUG_UPDATE, "HTML document detected!");
-			g_string_append (ctxt->feed->parseErrors, _("Source points to HTML document."));
+	/* 3.) None of the feed formats did work, chance is high that we are
+	       working on a HTML documents. Let's look for feed links inside it! */
+	if (!success) {
+		ctxt->subscription->autoDiscoveryTries++;
+		if (ctxt->subscription->autoDiscoveryTries > AUTO_DISCOVERY_MAX_REDIRECTS) {
+			debug2 (DEBUG_UPDATE, "Stopping feed auto discovery (%s) after too many redirects (limit is %d)", subscription_get_source (ctxt->subscription), AUTO_DISCOVERY_MAX_REDIRECTS);
 		} else {
-			debug0(DEBUG_UPDATE, "neither a known feed type nor a HTML document!");
-			g_string_append (ctxt->feed->parseErrors, _("Could not determine the feed type."));
+			autoDiscovery = feed_parser_auto_discover (ctxt);
 		}
+	}
+
+	if (htmlDoc)
+		xmlFreeDoc (htmlDoc);
+	if (xmlDoc)
+		xmlFreeDoc (xmlDoc);
+
+	/* 4.) Update subscription error status */
+	if (!success && !autoDiscovery) {
+		/* Fuzzy test for HTML document */
+		if ((strstr (ctxt->data, "<html>") || strstr (ctxt->data, "<HTML>") ||
+		     strstr (ctxt->data, "<html ") || strstr (ctxt->data, "<HTML ")))
+			ctxt->subscription->error = FETCH_ERROR_DISCOVER;
 	} else {
-		debug1 (DEBUG_UPDATE, "discovered feed format: %s", feed_type_fhp_to_str(ctxt->feed->fhp));
+		if (ctxt->feed->fhp) {
+			debug1 (DEBUG_UPDATE, "discovered feed format: %s", feed_type_fhp_to_str (ctxt->feed->fhp));
+			ctxt->subscription->autoDiscoveryTries = 0;
+		} else {
+			/* Auto discovery found a link that is being processed
+			   asynchronously, for now we do not know wether it will
+			   succeed. Still our auto-discovery was successful. */
+		}
 		success = TRUE;
+		ctxt->subscription->error = FETCH_ERROR_NONE;
 	}
 
 	debug_exit ("feed_parse");
