@@ -1,7 +1,7 @@
 /**
  * @file default_source.c  default static feed list source
  * 
- * Copyright (C) 2005-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2014 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,98 +35,69 @@
 #include "fl_sources/node_source.h"
 
 /** lock to prevent feed list saving while loading */
-static gboolean feedlistImport = FALSE;
+static gboolean feedlistImport = TRUE;
 
 static gchar *
 default_source_source_get_feedlist (nodePtr node)
 {
-	return common_create_cache_filename (NULL, "feedlist", "opml");
+	return common_create_config_filename ("feedlist.opml");
 }
 
 static void
 default_source_import (nodePtr node) 
 {
-	gchar		*filename10;
-	gchar		*filename12;
-	gchar		*filename14;
-	gchar		*filename16;
-	gchar		*filename17;
 	gchar		*filename, *backupFilename;
 	gchar		*content;
 	gssize		length;
-	migrationMode	migration = 0;
 
 	debug_enter ("default_source_source_import");
 
-	/* start the import */
-	feedlistImport = TRUE;
+	g_assert (TRUE == feedlistImport);
 
-	/* build test file names */
-	filename10 = g_strdup_printf ("%s/.liferea/feedlist.opml", g_get_home_dir ());
-	filename12 = g_strdup_printf ("%s/.liferea_1.2/feedlist.opml", g_get_home_dir ());
-	filename14 = g_strdup_printf ("%s/.liferea_1.4/feedlist.opml", g_get_home_dir ());
-	filename16 = g_strdup_printf ("%s/.liferea_1.6/feedlist.opml", g_get_home_dir ());
-	filename17 = g_strdup_printf ("%s/.liferea_1.7/feedlist.opml", g_get_home_dir ());
 	filename = default_source_source_get_feedlist (node);
 	backupFilename = g_strdup_printf("%s.backup", filename);
 	
-	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		/* If feed list is missing, try migration. */
+	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
+		if (!import_OPML_feedlist (filename, node, FALSE, TRUE))
+			g_error ("Fatal: Feed list import failed! You might want to try to restore\n"
+			         "the feed list file %s from the backup in %s", filename, backupFilename);
 
-		/* Note: Starting with 1.3 migration needs to be done before feed list import... */
-		if (g_file_test (filename17, G_FILE_TEST_EXISTS)) {
-			migration_execute (MIGRATION_FROM_17);
-		} else if (g_file_test (filename16, G_FILE_TEST_EXISTS)) {
-			migration_execute (MIGRATION_FROM_16);
-		} else if (g_file_test (filename14, G_FILE_TEST_EXISTS)) {
-			migration_execute (MIGRATION_FROM_14);
-		} else if (g_file_test (filename12, G_FILE_TEST_EXISTS)) {
-			/* migration needs to be done after feed list import
-			   so we redirect the feed list OPML file name and
-			   import later */
-			g_free (filename);
-		     	filename = g_strdup (filename12);
-			migration = MIGRATION_FROM_12;
-		} else if (g_file_test (filename10, G_FILE_TEST_EXISTS)) {
-			/* same as 1.2->1.4: delayed migration... */
-			g_free (filename);
-			filename = g_strdup (filename10);
-			migration = MIGRATION_FROM_10;
+		/* upon successful import create a backup copy of the feed list */
+		if (g_file_get_contents (filename, &content, &length, NULL)) {
+			g_file_set_contents (backupFilename, content, length, NULL);
+			g_free (content);
 		}
-	}
+	} else {
+		/* If subscriptions could not be loaded try cache migration
+		   or provide a default feed list */
 
-	g_free (filename17);
-	g_free (filename16);
-	g_free (filename14);
-	g_free (filename12);
-	g_free (filename10);
+		gchar *filename14 = g_strdup_printf ("%s/.liferea_1.4/feedlist.opml", g_get_home_dir ());
+		gchar *filename16 = g_strdup_printf ("%s/.liferea_1.6/feedlist.opml", g_get_home_dir ());
+		gchar *filename18 = g_strdup_printf ("%s/.liferea_1.8/feedlist.opml", g_get_home_dir ());
+
+		if (g_file_test (filename18, G_FILE_TEST_EXISTS)) {
+			migration_execute (MIGRATION_FROM_18, node);
+		} else if (g_file_test (filename16, G_FILE_TEST_EXISTS)) {
+			migration_execute (MIGRATION_FROM_16, node);
+		} else if (g_file_test (filename14, G_FILE_TEST_EXISTS)) {
+			migration_execute (MIGRATION_FROM_14, node);
+		} else {
+			gchar *filename = common_get_localized_filename (PACKAGE_DATA_DIR "/" PACKAGE "/opml/feedlist_%s.opml");
+			if (!filename)
+				g_error ("Fatal: No migration possible and no default feedlist found!");
 	
-	/* check for default feed list import */
-	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		/* if there is no feedlist.opml we provide a default feed list */
-		g_free (filename);
-		
-		filename = common_get_localized_filename (PACKAGE_DATA_DIR "/" PACKAGE "/opml/feedlist_%s.opml");
+			if (!import_OPML_feedlist (filename, node, FALSE, TRUE))
+				g_error ("Fatal: Feed list import failed!");
+			g_free (filename);
+		}
 
-		if (!filename)
-			g_error ("No default feedlist found.");
-	}
-
-	if (!import_OPML_feedlist (filename, node, FALSE, TRUE))
-		g_error ("Fatal: Feed list import failed! You might want to try to restore\n"
-		         "the feed list file %s from the backup in %s", filename, backupFilename);
-
-	/* upon successful import create a backup copy of the feed list */
-	if (g_file_get_contents (filename, &content, &length, NULL)) {
-		g_file_set_contents (backupFilename, content, length, NULL);
-		g_free (content);
+		g_free (filename18);
+		g_free (filename16);
+		g_free (filename14);
 	}
 
 	g_free (filename);
 	g_free (backupFilename);
-			
-	if (migration)
-		migration_execute (migration);
 	
 	feedlistImport = FALSE;
 
@@ -152,12 +123,6 @@ default_source_export (nodePtr node)
 	debug_exit ("default_source_source_export");
 }
 
-static void
-default_source_update (nodePtr node)
-{	
-	node_foreach_child_data (node, node_update_subscription, GUINT_TO_POINTER (0));
-}
-
 static void
 default_source_auto_update (nodePtr node)
 {	
@@ -207,10 +172,13 @@ static void default_source_deinit (void) { }
 static struct nodeSourceType nst = {
 	.id			= "fl_default",
 	.name			= "Static Feed List",
-	.description		= "The default feed list source. Should never be added manually. If you see this then something went wrong!",
 	.capabilities		= NODE_SOURCE_CAPABILITY_IS_ROOT |
 				  NODE_SOURCE_CAPABILITY_HIERARCHIC_FEEDLIST |
+	                          NODE_SOURCE_CAPABILITY_ADD_FEED |
+	                          NODE_SOURCE_CAPABILITY_ADD_FOLDER |
 				  NODE_SOURCE_CAPABILITY_WRITABLE_FEEDLIST,
+	.feedSubscriptionType	= NULL,
+	.sourceSubscriptionType	= NULL,
 	.source_type_init	= default_source_init,
 	.source_type_deinit	= default_source_deinit,
 	.source_new		= NULL,
@@ -218,12 +186,18 @@ static struct nodeSourceType nst = {
 	.source_import		= default_source_import,
 	.source_export		= default_source_export,
 	.source_get_feedlist	= default_source_source_get_feedlist,
-	.source_update		= default_source_update,
 	.source_auto_update	= default_source_auto_update,
 	.free 			= NULL,
 	.add_subscription	= default_source_add_subscription,
 	.add_folder		= default_source_add_folder,
-	.remove_node		= default_source_remove_node
+	.remove_node		= default_source_remove_node,
+	.convert_to_local	= NULL
 };
 
-nodeSourceTypePtr default_source_get_type (void) { return &nst; }
+nodeSourceTypePtr
+default_source_get_type (void)
+{
+	nst.feedSubscriptionType = feed_get_subscription_type ();
+
+	return &nst;
+}
