@@ -22,6 +22,7 @@
 #include <libxml/uri.h>
 
 #include "common.h"
+#include "conf.h"
 #include "debug.h"
 #include "feed.h"
 #include "feedlist.h"
@@ -55,7 +56,7 @@ htmlview_render_item (itemPtr item,
 {
 	renderParamPtr	params;
 	gchar		*output = NULL, *baseUrl = NULL;
-	nodePtr		node, selected;
+	nodePtr		node;
 	xmlDocPtr 	doc;
 	xmlNodePtr 	xmlNode;
 	const gchar     *text_direction = NULL;
@@ -108,11 +109,16 @@ htmlview_start_output (GString *buffer,
                        const gchar *base,
 		       gboolean css)
 {
+	gboolean readerMode = FALSE;
+
+	conf_get_bool_value (ENABLE_READER_MODE, &readerMode);
+
 	/* Prepare HTML boilderplate */
 	g_string_append (buffer, "<!DOCTYPE html>\n");
 	g_string_append (buffer, "<html>\n");
 	g_string_append (buffer, "<head>\n<title>HTML View</title>");
 	g_string_append (buffer, "<script src='file://" PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "js" G_DIR_SEPARATOR_S "Readability.js'></script>");
+	// FIXME: consider adding CSP meta tag here as e.g. Firefox reader mode page does
 	g_string_append (buffer, "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" />");
 
 	if (base)
@@ -127,12 +133,19 @@ htmlview_start_output (GString *buffer,
 	if (css)
 		g_string_append (buffer, render_get_css (TRUE /* external CSS supported */));
 
-	g_string_append (buffer,  "<script language=\"javascript\" type=\"text/javascript\">"
-	"\nif (window.addEventListener) {"
-	"\n	var documentIsReady = function() {"
-        "\n       	try {"
-	"\n			window.removeEventListener('load', documentIsReady);"
+	g_string_append (buffer,  "<script language=\"javascript\" type=\"text/javascript\">\nvar readerEnabled = ");
+	g_string_append (buffer, readerMode?"true":"false");
+	g_string_append (buffer, ";\n"
+	"\nfunction load() {"
+	"\n		window.removeEventListener('load', documentIsReady);"
 	"\n"
+	"\n		if(false == readerEnabled) {"
+	"\n			document.body.innerHTML = decodeURIComponent(content);"
+	"\n			var readerbtn = document.querySelector('.head_readerbtn');"
+	"\n			readerbtn.classList.add('inactive')"
+	"\n			return;"
+	"\n		}"
+	"\n       	try {"
 	"\n			// Add all content in shadow DOM and split decoration from content"
 	"\n			// only pass the content to Readability.js"
 	"\n			var documentClone = document.cloneNode(true);"
@@ -152,8 +165,13 @@ htmlview_start_output (GString *buffer,
 	"\n			document.getElementById('content').innerHTML=article.content"
 	"\n		} catch(e) {"
 	"\n			console.log('Reader mode failed ('+e+')');"
-	"\n			document.body.innerHTML = decodeURIComponent(content);"
+	"\n			readerEnabled = false;"
+	"\n			load()"
 	"\n		}"
+	"\n}"
+	"\nif (window.addEventListener) {"
+	"\n	var documentIsReady = function() {"
+	"\n             load();"
 	"\n	};"
 	"\n	window.addEventListener('load', function() { window.setTimeout(documentIsReady, 0); });"
 	"\n}"
@@ -177,7 +195,6 @@ htmlview_finish_output (GString *buffer, gchar *content)
 void
 htmlview_update (LifereaHtmlView *htmlview, itemViewMode mode)
 {
-	GSList		*iter;
 	GString		*output;
 	nodePtr		node = feedlist_get_selected ();
 	itemPtr		item = NULL;
