@@ -190,6 +190,15 @@ item_make_link (itemPtr item)
 	return link;
 }
 
+const gchar *
+item_get_author(itemPtr item)
+{
+	gchar *author;
+
+	author = (gchar *)metadata_list_get (item->metadata, "author");
+	return author;
+}
+
 void
 item_unload (itemPtr item)
 {
