@@ -1,7 +1,7 @@
 /**
- * @file item_state.c   item state controller interface
+ * @file item_state.c   item state controller
  * 
- * Copyright (C) 2007-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2014 Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include "item_state.h"
 #include "itemset.h"
 #include "itemlist.h"
-#include "newsbin.h"
 #include "node.h"
 #include "vfolder.h"
 #include "fl_sources/node_source.h"
@@ -51,19 +50,15 @@ item_flag_state_changed (itemPtr item, gboolean newState)
 	/* 1. set value in memory */	
 	item->flagStatus = newState;
 
-	/* 2. propagate to vfolders */
-	vfolder_foreach_data (vfolder_merge_item, item);
-	vfolder_foreach (node_update_counters);
-
-	/* 3. save state to DB */
+	/* 2. save state to DB */
 	db_item_state_update (item);
 
+	/* 3. update vfolder counters */
+	vfolder_foreach (node_update_counters);
+
 	/* 4. update item list GUI state */
 	itemlist_update_item (item);
 
-	/* 5. update notification statistics */
-	feedlist_reset_new_item_count ();
-
 	/* no duplicate state propagation to avoid copies 
 	   in the "Important" search folder */
 }
@@ -93,13 +88,12 @@ item_read_state_changed (itemPtr item, gboolean newState)
 	item->readStatus = newState;
 	item->updateStatus = FALSE;
 
-	/* 2. propagate to vfolders */
-	vfolder_foreach_data (vfolder_merge_item, item);
-	vfolder_foreach (node_update_counters);
-	
-	/* 3. apply to DB */
+	/* 2. apply to DB */
 	db_item_state_update (item);
 
+	/* 3. propagate to vfolders */
+	vfolder_foreach (node_update_counters);
+	
 	/* 4. update item list GUI state */
 	itemlist_update_item (item);
 
@@ -107,10 +101,7 @@ item_read_state_changed (itemPtr item, gboolean newState)
 	node = node_from_id (item->nodeId);
 	node_update_counters (node);
 
-	/* 6. update notification statistics */
-	feedlist_reset_new_item_count ();
-
-	/* 7. duplicate state propagation */
+	/* 6. duplicate state propagation */
 	if (item->validGuid) {
 		GSList *duplicates, *iter;
 
@@ -147,10 +138,7 @@ void
 itemset_mark_read (nodePtr node)
 {
 	itemSetPtr	itemSet;
-	
-	if (!node->unreadCount)
-		return;
-	
+
 	itemSet = node_get_itemset (node);
 	GList *iter = itemSet->ids;
 	while (iter) {
@@ -158,14 +146,10 @@ itemset_mark_read (nodePtr node)
 		itemPtr item = item_load (id);
 		if (item) {
 			if (!item->readStatus) {
-				nodePtr node;
-				
-				node = node_from_id (item->nodeId);
+				nodePtr node = node_from_id (item->nodeId);
 				if (node) {
 					item_state_set_recount_flag (node);
 					node_source_item_mark_read (node, item, TRUE);
-				} else {
-					g_warning ("itemset_mark_read() on lost item (id=%lu, node id=%s)!", item->id, item->nodeId);
 				}
 
 				debug_start_measurement (DEBUG_GUI);
@@ -188,6 +172,8 @@ itemset_mark_read (nodePtr node)
 		}
 		iter = g_list_next (iter);
 	}
+
+	// FIXME: why not call itemset_free (itemSet); here? Crashes!
 }
 
 void
