@@ -405,7 +405,18 @@ render_xml (xmlDocPtr doc, const gchar *xsltName, renderParamPtr paramSet)
 		return NULL;
 	}
 
-	/* for debugging use: xsltSaveResultToFile(stdout, resDoc, xslt); */
+	/*
+	   for XLST input debugging use:
+
+		xmlChar *buffer;
+		gint buffersize;
+		xmlDocDumpFormatMemory(doc, &buffer, &buffersize, 1);
+		printf("%s", (char *) buffer);
+
+           for XSLT output debugging use:
+
+           	xsltSaveResultToFile(stdout, resDoc, xslt);
+         */
 
 	/* save results into return string */
 	buf = xmlAllocOutputBuffer (NULL);
