@@ -1,7 +1,7 @@
 /**
  * @file auth_dialog.c  authentication dialog
  *
- * Copyright (C) 2007-2016  Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2007-2018  Lars Windolf <lars.windolf@gmx.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,34 +26,29 @@
 #include "debug.h"
 #include "ui/liferea_dialog.h"
 
-#define AUTH_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), AUTH_DIALOG_TYPE, AuthDialogPrivate))
-
-struct AuthDialogPrivate {
+struct _AuthDialog {
+	GObject parentInstance;
 
 	subscriptionPtr subscription;
-	
+
 	GtkWidget *dialog;
 	GtkWidget *username;
-	GtkWidget *password;	
-	
+	GtkWidget *password;
+
 	gint flags;
 };
 
-static GObjectClass *parent_class = NULL;
-
 G_DEFINE_TYPE (AuthDialog, auth_dialog, G_TYPE_OBJECT);
 
 static void
 auth_dialog_finalize (GObject *object)
 {
 	AuthDialog *ad = AUTH_DIALOG (object);
-	
-	if (ad->priv->subscription != NULL)
-		ad->priv->subscription->activeAuth = FALSE;
-	
-	gtk_widget_destroy (ad->priv->dialog);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	if (ad->subscription != NULL)
+		ad->subscription->activeAuth = FALSE;
+
+	gtk_widget_destroy (ad->dialog);
 }
 
 static void
@@ -61,25 +56,21 @@ auth_dialog_class_init (AuthDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	object_class->finalize = auth_dialog_finalize;
-
-	g_type_class_add_private (object_class, sizeof(AuthDialogPrivate));
 }
 
 static void
 on_authdialog_response (GtkDialog *dialog,
                         gint response_id,
-			gpointer user_data) 
+			gpointer user_data)
 {
 	AuthDialog *ad = AUTH_DIALOG (user_data);
-	
-	if (response_id == GTK_RESPONSE_OK) {	
-		subscription_set_auth_info (ad->priv->subscription,
-		                            gtk_entry_get_text (GTK_ENTRY (ad->priv->username)),
-		                            gtk_entry_get_text (GTK_ENTRY (ad->priv->password)));
-		subscription_update (ad->priv->subscription, ad->priv->flags);
+
+	if (response_id == GTK_RESPONSE_OK) {
+		subscription_set_auth_info (ad->subscription,
+		                            gtk_entry_get_text (GTK_ENTRY (ad->username)),
+		                            gtk_entry_get_text (GTK_ENTRY (ad->password)));
+		subscription_update (ad->subscription, ad->flags);
 	}
 
 	g_object_unref (ad);
@@ -93,14 +84,14 @@ auth_dialog_load (AuthDialog *ad,
 	gchar			*promptStr;
 	gchar			*source = NULL;
 	xmlURIPtr		uri;
-	
+
 	subscription->activeAuth = TRUE;
-	
-	ad->priv->subscription = subscription;
-	ad->priv->flags = flags;
-	
-	uri = xmlParseURI (subscription_get_source (ad->priv->subscription));
-	
+
+	ad->subscription = subscription;
+	ad->flags = flags;
+
+	uri = xmlParseURI (subscription_get_source (ad->subscription));
+
 	if (uri) {
 		if (uri->user) {
 			gchar *user = uri->user;
@@ -108,9 +99,9 @@ auth_dialog_load (AuthDialog *ad,
 			if(pass) {
 				pass[0] = '\0';
 				pass++;
-				gtk_entry_set_text (GTK_ENTRY (ad->priv->password), pass);
+				gtk_entry_set_text (GTK_ENTRY (ad->password), pass);
 			}
-			gtk_entry_set_text (GTK_ENTRY (ad->priv->username), user);
+			gtk_entry_set_text (GTK_ENTRY (ad->username), user);
 			xmlFree (uri->user);
 			uri->user = NULL;
 		}
@@ -119,11 +110,11 @@ auth_dialog_load (AuthDialog *ad,
 		source = (gchar *) xmlSaveUri (uri);
 		xmlFreeURI (uri);
 	}
-	
+
 	promptStr = g_strdup_printf ( _("Enter the username and password for \"%s\" (%s):"),
-	                             node_get_title (ad->priv->subscription->node),
+	                             node_get_title (ad->subscription->node),
 	                             source?source:_("Unknown source"));
-	gtk_label_set_text (GTK_LABEL (liferea_dialog_lookup (ad->priv->dialog, "prompt")), promptStr);
+	gtk_label_set_text (GTK_LABEL (liferea_dialog_lookup (ad->dialog, "prompt")), promptStr);
 	g_free (promptStr);
 	if (source)
 		xmlFree (source);
@@ -132,28 +123,26 @@ auth_dialog_load (AuthDialog *ad,
 static void
 auth_dialog_init (AuthDialog *ad)
 {
-	ad->priv = AUTH_DIALOG_GET_PRIVATE (ad);
-	
-	ad->priv->dialog = liferea_dialog_new ("auth");
-	ad->priv->username = liferea_dialog_lookup (ad->priv->dialog, "usernameEntry");
-	ad->priv->password = liferea_dialog_lookup (ad->priv->dialog, "passwordEntry");
-	
-	g_signal_connect (G_OBJECT (ad->priv->dialog), "response", G_CALLBACK (on_authdialog_response), ad);
+	ad->dialog = liferea_dialog_new ("auth");
+	ad->username = liferea_dialog_lookup (ad->dialog, "usernameEntry");
+	ad->password = liferea_dialog_lookup (ad->dialog, "passwordEntry");
 
-	gtk_widget_show_all (ad->priv->dialog);
+	g_signal_connect (G_OBJECT (ad->dialog), "response", G_CALLBACK (on_authdialog_response), ad);
+
+	gtk_widget_show_all (ad->dialog);
 }
 
 
 AuthDialog *
-auth_dialog_new (subscriptionPtr subscription, gint flags) 
+auth_dialog_new (subscriptionPtr subscription, gint flags)
 {
 	AuthDialog *ad;
-	
+
 	if (subscription->activeAuth) {
 		debug0 (DEBUG_UPDATE, "Missing/wrong authentication. Skipping, as a dialog is already active.");
 		return NULL;
 	}
-	
+
 	ad = AUTH_DIALOG (g_object_new (AUTH_DIALOG_TYPE, NULL));
 	auth_dialog_load(ad, subscription, flags);
 	return ad;
