@@ -122,7 +122,7 @@ struct _ItemListView {
 
 	GtkTreeView	*treeview;
 	GtkWidget 	*ilscrolledwindow;	/*<< The complete ItemListView widget */
-	GSList      *item_ids;		/*<< list of all currently known item ids */
+	GSList		*item_ids;		/*<< list of all currently known item ids */
 
 	gboolean	batch_mode;		/*<< TRUE if we are in batch adding mode */
 	GtkTreeStore	*batch_itemstore;	/*<< GtkTreeStore prepared unattached and to be set on update() */
@@ -464,7 +464,7 @@ item_list_title_alignment (gchar *title)
 		return 1.;
 }
 
-static void 
+static void
 item_list_view_update_item_internal (ItemListView *ilv, itemPtr item, GtkTreeIter *iter, nodePtr node)
 {
 	GtkTreeStore	*itemstore;
@@ -553,22 +553,6 @@ item_list_view_update_item (ItemListView *ilv, itemPtr item)
         item_list_view_update_item_internal (ilv, item, &iter, NULL);
 }
 
-static void
-item_list_view_update_item_foreach (gpointer key,
-                                    gpointer value,
-                                    gpointer user_data)
-{
-	itemPtr 	item;
-
-	item = item_load (GPOINTER_TO_UINT (key) /* id */);
-	if (!item)
-		return;
-
-	item_list_view_update_item (ITEM_LIST_VIEW (user_data), item);
-
-	item_unload (item);
-}
-
 void
 item_list_view_update_all_items (ItemListView *ilv)
 {
@@ -920,7 +904,6 @@ item_list_view_create (gboolean wide)
 static void
 item_list_view_add_item_to_tree_store (ItemListView *ilv, GtkTreeStore *itemstore, itemPtr item)
 {
-	gint		state = 0;
 	nodePtr		node;
 	GtkTreeIter	iter;
 	gboolean	exists = FALSE;
@@ -932,8 +915,7 @@ item_list_view_add_item_to_tree_store (ItemListView *ilv, GtkTreeStore *itemstor
         if (!ilv->batch_mode)
             exists = item_list_view_id_to_iter (ilv, item->id, &iter);
 
-	if (!exists)
-	{
+	if (!exists) {
 		gtk_tree_store_prepend (itemstore, &iter, NULL);
 		ilv->item_ids = g_slist_prepend (ilv->item_ids, GUINT_TO_POINTER (item->id));
 	}
