@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "ui/popup_menu.h"
@@ -34,7 +34,6 @@
 #include "social.h"
 #include "vfolder.h"
 #include "ui/enclosure_list_view.h"
-#include "ui/feed_list_node.h"
 #include "ui/feed_list_view.h"
 #include "ui/item_list_view.h"
 #include "ui/itemview.h"
@@ -44,21 +43,12 @@
 
 #define UI_POPUP_ITEM_IS_TOGGLE		1
 
-
 static void
-ui_popup_menu_at_pos (GtkWidget *menu, GtkMenuPositionFunc func, guint button, guint32 activate_time, gpointer user_data)
+ui_popup_menu (GtkWidget *menu, const GdkEvent *event)
 {
 	g_signal_connect_after (G_OBJECT(menu), "unmap-event", G_CALLBACK(gtk_widget_destroy), NULL);
-
 	gtk_widget_show_all (menu);
-
-	gtk_menu_popup (GTK_MENU(menu), NULL, NULL, func, user_data, button, activate_time);
-}
-
-static void
-ui_popup_menu (GtkWidget *menu, guint button, guint32 activate_time)
-{
-	ui_popup_menu_at_pos(menu, NULL, button, activate_time, NULL);
+	gtk_menu_popup_at_pointer (GTK_MENU(menu), event);
 }
 
 static GtkWidget*
@@ -86,11 +76,14 @@ static const GActionEntry ui_popup_item_gaction_entries[] = {
 	{"copy-item-to-newsbin", on_action_copy_to_newsbin, "(umt)", NULL, NULL},
 	{"toggle-item-read-status", on_toggle_unread_status, "t", NULL, NULL},
 	{"toggle-item-flag", on_toggle_item_flag, "t", NULL, NULL},
-	{"remove-item", on_action_remove_item, "t", NULL, NULL}
+	{"remove-item", on_action_remove_item, "t", NULL, NULL},
+	{"open-item-in-tab", on_action_launch_item_in_tab, "t", NULL, NULL},
+	{"open-item-in-browser", on_action_launch_item_in_browser, "t", NULL, NULL},
+	{"open-item-in-external-browser", on_action_launch_item_in_external_browser, "t", NULL, NULL}
 };
 
 void
-ui_popup_item_menu (itemPtr item, guint button, guint32 activate_time)
+ui_popup_item_menu (itemPtr item, const GdkEvent *event)
 {
 	GtkWidget	*menu;
 	GMenu		*menu_model, *section;
@@ -98,24 +91,32 @@ ui_popup_item_menu (itemPtr item, guint button, guint32 activate_time)
 	GSimpleActionGroup *action_group;
 	GSList		*iter;
 	gchar		*text, *item_link;
+	const gchar *author;
 
 	item_link = item_make_link (item);
 	menu_model = g_menu_new ();
 	menu_item = g_menu_item_new (NULL, NULL);
+	author = item_get_author(item);
 
 	section = g_menu_new ();
 	g_menu_item_set_label (menu_item, _("Open In _Tab"));
-	g_menu_item_set_action_and_target (menu_item, "app.open-link-in-tab", "s", item_link);
+	g_menu_item_set_action_and_target (menu_item, "item.open-item-in-tab", "t", (guint64) item->id);
 	g_menu_append_item (section, menu_item);
 
 	g_menu_item_set_label (menu_item, _("_Open In Browser"));
-	g_menu_item_set_action_and_target (menu_item, "app.open-link-in-browser", "s", item_link);
+	g_menu_item_set_action_and_target (menu_item, "item.open-item-in-browser", "t", (guint64) item->id);
 	g_menu_append_item (section, menu_item);
 
 	g_menu_item_set_label (menu_item, _("Open In _External Browser"));
-	g_menu_item_set_action_and_target (menu_item, "app.open-link-in-external-browser", "s", item_link);
+	g_menu_item_set_action_and_target (menu_item, "item.open-item-in-external-browser", "t", (guint64) item->id);
 	g_menu_append_item (section, menu_item);
 
+	if(author){
+		g_menu_item_set_label (menu_item, _("Email The Author"));
+		g_menu_item_set_action_and_target (menu_item, "app.email-the-author", "t", (guint64) item->id);
+		g_menu_append_item (section, menu_item);
+	}
+
 	g_menu_append_section (menu_model, NULL, G_MENU_MODEL (section));
 	g_object_unref (section);
 
@@ -186,12 +187,11 @@ ui_popup_item_menu (itemPtr item, guint button, guint32 activate_time)
 	/* The menu has to be attached to an application window or one of its children for access to app actions.*/
 	gtk_menu_attach_to_widget (GTK_MENU (menu), liferea_shell_lookup ("mainwindow"), NULL);
 	g_object_unref (menu_model);
-	ui_popup_menu (menu, button, activate_time);
+	ui_popup_menu (menu, event);
 }
 
 void
-ui_popup_enclosure_menu (enclosurePtr enclosure, guint button,
-			 guint32 activate_time)
+ui_popup_enclosure_menu (enclosurePtr enclosure, const GdkEvent *event)
 {
 	GtkWidget	*menu;
 
@@ -201,7 +201,7 @@ ui_popup_enclosure_menu (enclosurePtr enclosure, guint button,
 	ui_popup_add_menuitem (menu, _("Save As..."), on_popup_save_enclosure, enclosure, 0);
 	ui_popup_add_menuitem (menu, _("Copy Link Location"), on_popup_copy_enclosure, enclosure, 0);
 
-	ui_popup_menu (menu, button, activate_time);
+	ui_popup_menu (menu, event);
 }
 
 /* popup callback wrappers */
@@ -216,14 +216,14 @@ static void
 ui_popup_properties (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
 	nodePtr node = (nodePtr) user_data;
-	
+
 	NODE_TYPE (node)->request_properties (node);
 }
 
 static void
 ui_popup_delete (GSimpleAction *action, GVariant *parameter, gpointer user_data)
 {
-	feed_list_node_remove ((nodePtr)user_data);
+	feed_list_view_remove ((nodePtr)user_data);
 }
 
 static void
@@ -249,12 +249,12 @@ static const GActionEntry ui_popup_node_gaction_entries[] = {
   {"node-update", on_menu_update, NULL, NULL, NULL}
 };
 
-/** 
+/**
  * Shows popup menus for the feed list depending on the
  * node type.
  */
 static void
-ui_popup_node_menu (nodePtr node, gboolean validSelection, guint button, guint32 activate_time)
+ui_popup_node_menu (nodePtr node, gboolean validSelection, const GdkEvent *event)
 {
 	GtkWidget		*menu;
 	GMenu 			*menu_model, *section;
@@ -290,10 +290,10 @@ ui_popup_node_menu (nodePtr node, gboolean validSelection, guint button, guint32
 
 			if (node_can_add_child_feed (node))
 				g_menu_append (submenu, _("New _Subscription..."), "app.new-subscription");
-			
+
 			if (node_can_add_child_folder (node))
 				g_menu_append (submenu, _("New _Folder..."), "app.new-folder");
-				
+
 			if (isRoot) {
 				g_menu_append (submenu, _("New S_earch Folder..."), "app.new-vfolder");
 				g_menu_append (submenu, _("New S_ource..."), "app.new-source");
@@ -303,7 +303,7 @@ ui_popup_node_menu (nodePtr node, gboolean validSelection, guint button, guint32
 			g_menu_append_submenu (section, _("_New"), G_MENU_MODEL (submenu));
 			g_object_unref (submenu);
 		}
-		
+
 		if (isRoot && node->children) {
 			/* Ending section and starting a new one to get a separator : */
 			g_menu_append_section (menu_model, NULL, G_MENU_MODEL (section));
@@ -355,13 +355,13 @@ ui_popup_node_menu (nodePtr node, gboolean validSelection, guint button, guint32
 	gtk_menu_attach_to_widget (GTK_MENU (menu), liferea_shell_lookup ("mainwindow"), NULL);
 	g_object_unref (menu_model);
 
-	ui_popup_menu (menu, button, activate_time);
+	ui_popup_menu (menu, event);
 }
 
 /* mouse button handler */
 gboolean
 on_mainfeedlist_button_press_event (GtkWidget *widget,
-                                    GdkEventButton *event,
+                                    GdkEvent *event,
                                     gpointer user_data)
 {
 	GdkEventButton 	*eb;
@@ -379,8 +379,8 @@ on_mainfeedlist_button_press_event (GtkWidget *widget,
 
 	eb = (GdkEventButton*)event;
 
-	/* determine node */	
-	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview), event->x, event->y, &path, NULL, NULL, NULL)) {
+	/* determine node */
+	if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (treeview), eb->x, eb->y, &path, NULL, NULL, NULL)) {
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
 		gtk_tree_model_get_iter (model, &iter, path);
 		gtk_tree_path_free (path);
@@ -389,7 +389,7 @@ on_mainfeedlist_button_press_event (GtkWidget *widget,
 		selected = FALSE;
 		node = feedlist_get_root ();
 	}
-	
+
 	/* apply action */
 	switch (eb->button) {
 		default:
@@ -412,10 +412,10 @@ on_mainfeedlist_button_press_event (GtkWidget *widget,
 			}
 
 			gtk_widget_grab_focus (widget);
-			ui_popup_node_menu (node, selected, eb->button, eb->time);
+			ui_popup_node_menu (node, selected, event);
 			break;
 	}
-			
+
 	return TRUE;
 }
 
@@ -440,6 +440,6 @@ on_mainfeedlist_popup_menu (GtkWidget *widget,
 		node = feedlist_get_root ();
 	}
 
-	ui_popup_node_menu (node, selected, 3, gtk_get_current_event_time ());
+	ui_popup_node_menu (node, selected, NULL);
 	return TRUE;
 }
