@@ -1,7 +1,7 @@
 /**
  * @file update.c  generic update request and state processing
  *
- * Copyright (C) 2003-2020 Lars Windolf <lars.windolf@gmx.de>
+ * Copyright (C) 2003-2021 Lars Windolf <lars.windolf@gmx.de>
  * Copyright (C) 2004-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  * Copyright (C) 2009 Adrian Bunk <bunk@users.sourceforge.net>
  *
@@ -28,8 +28,6 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 
-#include <libpeas/peas-extension-set.h>
-
 #include <unistd.h>
 #include <stdio.h>
 #if !defined (G_OS_WIN32) || defined (HAVE_SYS_WAIT_H)
@@ -293,6 +291,31 @@ update_job_get_state (updateJobPtr job)
 	return job->state;
 }
 
+static void
+update_job_show_count_foreach_func (gpointer data, gpointer user_data)
+{
+	updateJobPtr	job = (updateJobPtr)data;
+	guint		*count = (guint *)user_data;
+
+	// Count all subscription jobs (ignore HTML5 and favicon requests)
+	if (!(job->flags & FEED_REQ_NO_FEED))
+		(*count)++;
+}
+
+static guint maxcount = 0;
+
+void
+update_jobs_get_count (guint *count, guint *max)
+{
+	*count = 0;
+	g_slist_foreach (jobs, update_job_show_count_foreach_func, count);
+
+	if (*count > maxcount)
+		maxcount = *count;
+
+	*max = maxcount;
+}
+
 static void
 update_job_free (updateJobPtr job)
 {
@@ -308,7 +331,7 @@ update_job_free (updateJobPtr job)
 
 /* filter idea (and some of the code) was taken from Snownews */
 static gchar *
-update_exec_filter_cmd (gchar *cmd, gchar *data, gchar **errorOutput, size_t *size)
+update_exec_filter_cmd (updateJobPtr job)
 {
 	int		fd, status;
 	gchar		*command;
@@ -316,47 +339,48 @@ update_exec_filter_cmd (gchar *cmd, gchar *data, gchar **errorOutput, size_t *si
 	char		*tmpfilename;
 	char		*out = NULL;
 	FILE		*file, *p;
+	size_t		size = 0;
 
-	*errorOutput = NULL;
 	tmpfilename = g_build_filename (tmpdir, "liferea-XXXXXX", NULL);
 
-	fd = g_mkstemp(tmpfilename);
+	fd = g_mkstemp (tmpfilename);
 
-	if(fd == -1) {
-		debug1(DEBUG_UPDATE, "Error opening temp file %s to use for filtering!", tmpfilename);
-		*errorOutput = g_strdup_printf(_("Error opening temp file %s to use for filtering!"), tmpfilename);
-		g_free(tmpfilename);
+	if (fd == -1) {
+		debug1 (DEBUG_UPDATE, "Error opening temp file %s to use for filtering!", tmpfilename);
+		job->result->filterErrors = g_strdup_printf (_("Error opening temp file %s to use for filtering!"), tmpfilename);
+		g_free (tmpfilename);
 		return NULL;
 	}
 
-	file = fdopen(fd, "w");
-	fwrite(data, strlen(data), 1, file);
-	fclose(file);
+	file = fdopen (fd, "w");
+	fwrite (job->result->data, strlen (job->result->data), 1, file);
+	fclose (file);
 
-	*size = 0;
-	command = g_strdup_printf("%s < %s", cmd, tmpfilename);
-	p = popen(command, "r");
-	g_free(command);
-	if(NULL != p) {
-		while(!feof(p) && !ferror(p)) {
+	command = g_strdup_printf("%s < %s", job->request->filtercmd, tmpfilename);
+	p = popen (command, "r");
+	if (NULL != p) {
+		while (!feof (p) && !ferror (p)) {
 			size_t len;
-			out = g_realloc(out, *size+1025);
-			len = fread(&out[*size], 1, 1024, p);
-			if(len > 0)
-				*size += len;
+			out = g_realloc (out, size + 1025);
+			len = fread (&out[size], 1, 1024, p);
+			if (len > 0)
+				size += len;
 		}
-		status = pclose(p);
-		if(!(WIFEXITED(status) && WEXITSTATUS(status) == 0)) {
-			*errorOutput = g_strdup_printf(_("%s exited with status %d"),
-			                              cmd, WEXITSTATUS(status));
-			*size = 0;
+		status = pclose (p);
+		if (!(WIFEXITED (status) && WEXITSTATUS (status) == 0)) {
+			debug2 (DEBUG_UPDATE, "%s exited with status %d!", command, WEXITSTATUS(status));
+			job->result->filterErrors = g_strdup_printf (_("%s exited with status %d"), command, WEXITSTATUS(status));
+			size = 0;
 		}
-		out[*size] = '\0';
+		if (out)
+			out[size] = '\0';
 	} else {
-		g_warning(_("Error: Could not open pipe \"%s\""), command);
-		*errorOutput = g_strdup_printf(_("Error: Could not open pipe \"%s\""), command);
+		g_warning (_("Error: Could not open pipe \"%s\""), command);
+		job->result->filterErrors = g_strdup_printf (_("Error: Could not open pipe \"%s\""), command);
 	}
+
 	/* Clean up. */
+	g_free (command);
 	unlink (tmpfilename);
 	g_free (tmpfilename);
 	return out;
@@ -423,23 +447,20 @@ static void
 update_apply_filter (updateJobPtr job)
 {
 	gchar	*filterResult;
-	size_t	len = 0;
 
 	g_assert (NULL == job->result->filterErrors);
 
 	/* we allow two types of filters: XSLT stylesheets and arbitrary commands */
 	if ((strlen (job->request->filtercmd) > 4) &&
-	    (0 == strcmp (".xsl", job->request->filtercmd + strlen (job->request->filtercmd) - 4))) {
+	    (0 == strcmp (".xsl", job->request->filtercmd + strlen (job->request->filtercmd) - 4)))
 		filterResult = update_apply_xslt (job);
-		len = strlen (filterResult);
-	} else {
-		filterResult = update_exec_filter_cmd (job->request->filtercmd, job->result->data, &(job->result->filterErrors), &len);
-	}
+	else
+		filterResult = update_exec_filter_cmd (job);
 
 	if (filterResult) {
 		g_free (job->result->data);
 		job->result->data = filterResult;
-		job->result->size = len;
+		job->result->size = strlen(filterResult);
 	}
 }
 
@@ -577,6 +598,7 @@ update_execute_request (gpointer owner,
 			updateFlags flags)
 {
 	updateJobPtr job;
+	gint count;
 
 	g_assert (request->options != NULL);
 	g_assert (request->source != NULL);
