@@ -110,7 +110,6 @@ typedef struct updateResult {
 	gchar 		*source;	/**< Location of the downloaded document, in case of redirects different from
 					     the one given along with the update request */
 
-	int		returncode;	/**< Download status (0=success, otherwise error) */
 	int		httpstatus;	/**< HTTP status. Set to 200 for any valid command, file access, etc.... Set to 0 for unknown */
 	gchar		*data;		/**< Downloaded data */
 	size_t		size;		/**< Size of downloaded data */
@@ -273,6 +272,16 @@ void update_job_cancel_by_owner (gpointer owner);
  */
 gint update_job_get_state (updateJobPtr job);
 
+/**
+* update_jobs_get_count:
+*
+* Query current count and max count of subscriptions in update queue
+*
+* @count:	gint ref to pass back nr of subscriptions in update
+* @maxcount:	gint ref to pass back max nr of subscriptions in update
+*/
+void update_jobs_get_count (guint *count, guint *maxcount);
+
 G_END_DECLS
 
 #endif
